# Copyright (C) 2023 Alessandro Iepure
#
# SPDX-License-Identifier: GPL-3.0-or-later

from gi.repository import Gdk, Gio, GLib
from pathlib import Path
import logging
from .logging.session_file_handler import SessionFileHandler
import faulthandler
import os

APP_ID = 'me.iepure.Ticketbooth'
VERSION = '1.0.3.1'
PREFIX = '/me/iepure/Ticketbooth'
APP_NAME = 'Ticket Booth'

schema = Gio.Settings.new(APP_ID)

data_dir = Path(GLib.get_user_data_dir())
cache_dir = Path(GLib.get_user_cache_dir())

poster_dir = data_dir / 'poster'
background_dir = data_dir / 'background'
series_dir = data_dir / 'series'

db = data_dir / 'data.db'

if not os.path.exists(data_dir/'logs'):
    os.makedirs(data_dir/'logs')
faulthandler.enable(file=open(data_dir/'logs'/'crash.log',"w"))

if '0' == 'True':
    DEBUG = True
    # TODO: change back to DEBUG
    logging.basicConfig(level=logging.DEBUG,
                        format='%(asctime)s - %(levelname)s - %(message)s',
                        filename=data_dir / 'logs' / 'ticketbooth.log')
else:
    DEBUG = False
    logging.basicConfig(level=logging.INFO,
                        format='%(asctime)s - %(levelname)s - %(message)s',
                        filename=data_dir / 'logs' / 'ticketbooth.log')

handler = SessionFileHandler(filename=data_dir / 'logs' / 'ticketbooth.log')
handler.setFormatter(logging.Formatter('%(asctime)s - %(levelname)s - %(message)s'))
logging.getLogger().addHandler(handler)

log_files = None
